Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(213)

Unified Diff: content/browser/service_worker/service_worker_response_info.h

Issue 2516353002: Introduce url_list to the Response scheme of CacheStorage. (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/service_worker/service_worker_response_info.h
diff --git a/content/browser/service_worker/service_worker_response_info.h b/content/browser/service_worker/service_worker_response_info.h
index 88bc1a6b4f462fb743f213697c1e453c2af8e731..7b5217412102b00800112622c6d76fa0cc0b036b 100644
--- a/content/browser/service_worker/service_worker_response_info.h
+++ b/content/browser/service_worker/service_worker_response_info.h
@@ -5,6 +5,8 @@
#ifndef CONTENT_BROWSER_SERVICE_WORKER_SERVICE_WORKER_RESPONSE_INFO_H_
#define CONTENT_BROWSER_SERVICE_WORKER_SERVICE_WORKER_RESPONSE_INFO_H_
+#include <vector>
+
#include "base/supports_user_data.h"
#include "content/common/content_export.h"
#include "content/common/service_worker/service_worker_types.h"
@@ -35,7 +37,7 @@ class CONTENT_EXPORT ServiceWorkerResponseInfo
bool was_fetched_via_service_worker,
bool was_fetched_via_foreign_fetch,
bool was_fallback_required,
- const GURL& original_url_via_service_worker,
+ const std::vector<GURL>& url_list_via_service_worker,
blink::WebServiceWorkerResponseType response_type_via_service_worker,
base::TimeTicks service_worker_start_time,
base::TimeTicks service_worker_ready_time,
@@ -61,13 +63,13 @@ class CONTENT_EXPORT ServiceWorkerResponseInfo
// run, which is implemented in the renderer.
bool was_fallback_required() const { return was_fallback_required_; }
// Returns the URL of the Response object the service worker passed to
// respondWith() to create this response. This URL is null if the response was
// programatically generated as in respondWith(new Response()). It is also
- // null if a service worker did not respond to the request or did not call
+ // empty if a service worker did not respond to the request or did not call
// respondWith().
- const GURL& original_url_via_service_worker() const {
- return original_url_via_service_worker_;
+ const std::vector<GURL>& url_list_via_service_worker() const {
+ return url_list_via_service_worker_;
}
blink::WebServiceWorkerResponseType response_type_via_service_worker() const {
return response_type_via_service_worker_;
@@ -91,7 +93,7 @@ class CONTENT_EXPORT ServiceWorkerResponseInfo
bool was_fetched_via_service_worker_ = false;
bool was_fetched_via_foreign_fetch_ = false;
bool was_fallback_required_ = false;
- GURL original_url_via_service_worker_;
+ std::vector<GURL> url_list_via_service_worker_;
blink::WebServiceWorkerResponseType response_type_via_service_worker_ =
blink::WebServiceWorkerResponseTypeDefault;
base::TimeTicks service_worker_start_time_;
@@ -61,13 +63,13 @@ class CONTENT_EXPORT ServiceWorkerResponseInfo
// run, which is implemented in the renderer.
bool was_fallback_required() const { return was_fallback_required_; }
- // Returns the URL of the Response object the service worker passed to
- // respondWith() to create this response. This URL is null if the response was
+ // Returns the URL list of the Response object the service worker passed to
+ // respondWith() to create this response. This is empty if the response was
// programatically generated as in respondWith(new Response()). It is also

Powered by Google App Engine
This is Rietveld 408576698